==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/InterfaceOperationMessageSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.InterfaceOperationSet;
import io.ciera.tool.sql.ooaofooa.component.impl.InterfaceOperationSetImpl;
import io.ciera.tool.sql.ooaofooa.message.InterfaceOperationMessage;
import io.ciera.tool.sql.ooaofooa.message.InterfaceOperationMessageSet;
import io.ciera.tool.sql.ooaofooa.message.SynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.SynchronousMessageSetImpl;

import java.util.Arrays;
import java.util.List;


public class InterfaceOperationMessageSetImpl extends InstanceSet<InterfaceOperationMessageSet,InterfaceOperationMessage> implements InterfaceOperationMessageSet {

    // attributes
    @Override
    public void setMsg_ID( UniqueId ref_Msg_ID ) throws XtumlException {
        for ( InterfaceOperationMessage interfaceoperationmessage : this ) interfaceoperationmessage.setMsg_ID( ref_Msg_ID );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( InterfaceOperationMessage interfaceoperationmessage : this ) interfaceoperationmessage.setId( ref_Id );
    }


    // selections
    @Override
    public SynchronousMessageSet R1020_is_a_SynchronousMessage() throws XtumlException {
        SynchronousMessageSet synchronousmessageset = new SynchronousMessageSetImpl();
        for ( InterfaceOperationMessage interfaceoperationmessage : this ) synchronousmessageset.add( interfaceoperationmessage.R1020_is_a_SynchronousMessage() );
        return synchronousmessageset;
    }
    @Override
    public InterfaceOperationSet R1022_sends_InterfaceOperation() throws XtumlException {
        InterfaceOperationSet interfaceoperationset = new InterfaceOperationSetImpl();
        for ( InterfaceOperationMessage interfaceoperationmessage : this ) interfaceoperationset.add( interfaceoperationmessage.R1022_sends_InterfaceOperation() );
        return interfaceoperationset;
    }


    @Override
    public InterfaceOperationMessage nullElement() {
        return InterfaceOperationMessageImpl.EMPTY_INTERFACEOPERATIONMESSAGE;
    }

    @Override
    public InterfaceOperationMessageSet emptySet() {
      return new InterfaceOperationMessageSetImpl();
    }

    @Override
    public InterfaceOperationMessageSet value() {
        return this;
    }

    @Override
    public List<InterfaceOperationMessage> elements() {
        return Arrays.asList(toArray(new InterfaceOperationMessage[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/InterfaceOperationMessageSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.InterfaceOperationSet;
import io.ciera.tool.sql.ooaofooa.component.impl.InterfaceOperationSetImpl;
import io.ciera.tool.sql.ooaofooa.message.InterfaceOperationMessage;
import io.ciera.tool.sql.ooaofooa.message.InterfaceOperationMessageSet;
import io.ciera.tool.sql.ooaofooa.message.SynchronousMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.SynchronousMessageSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class InterfaceOperationMessageSetImpl extends InstanceSet<InterfaceOperationMessageSet,InterfaceOperationMessage> implements InterfaceOperationMessageSet {

    public InterfaceOperationMessageSetImpl() {
    }

    public InterfaceOperationMessageSetImpl(Comparator<? super InterfaceOperationMessage> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( InterfaceOperationMessage interfaceoperationmessage : this ) interfaceoperationmessage.setId( ref_Id );
    }
    @Override
    public void setMsg_ID( UniqueId ref_Msg_ID ) throws XtumlException {
        for ( InterfaceOperationMessage interfaceoperationmessage : this ) interfaceoperationmessage.setMsg_ID( ref_Msg_ID );
    }


    // selections
    @Override
    public SynchronousMessageSet R1020_is_a_SynchronousMessage() throws XtumlException {
        SynchronousMessageSet synchronousmessageset = new SynchronousMessageSetImpl();
        for ( InterfaceOperationMessage interfaceoperationmessage : this ) synchronousmessageset.add( interfaceoperationmessage.R1020_is_a_SynchronousMessage() );
        return synchronousmessageset;
    }
    @Override
    public InterfaceOperationSet R1022_sends_InterfaceOperation() throws XtumlException {
        InterfaceOperationSet interfaceoperationset = new InterfaceOperationSetImpl();
        for ( InterfaceOperationMessage interfaceoperationmessage : this ) interfaceoperationset.add( interfaceoperationmessage.R1022_sends_InterfaceOperation() );
        return interfaceoperationset;
    }


    @Override
    public InterfaceOperationMessage nullElement() {
        return InterfaceOperationMessageImpl.EMPTY_INTERFACEOPERATIONMESSAGE;
    }

    @Override
    public InterfaceOperationMessageSet emptySet() {
      return new InterfaceOperationMessageSetImpl();
    }

    @Override
    public InterfaceOperationMessageSet emptySet(Comparator<? super InterfaceOperationMessage> comp) {
      return new InterfaceOperationMessageSetImpl(comp);
    }

    @Override
    public InterfaceOperationMessageSet value() {
        return this;
    }

    @Override
    public List<InterfaceOperationMessage> elements() {
        return Arrays.asList(toArray(new InterfaceOperationMessage[0]));
    }

}
